/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 02778
 |                   GAMBLING IMPACT AND BEHAVIOR STUDY
 |                      (DATASET 0001: ADULT SURVEY)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 02778-0001-statasetup.do)
 |
 **************************************************************************/

set mem 9m  /* Allocating 9 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.\n
**********************************************************/


label data "Gambling Impact and Behavior Study, Dataset 0001"

#delimit ;
label define A1_       1 "MALE" 2 "FEMALE" ;
label define A3_       -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define A5_       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define A7_       -3 "MISSING" -1 "REFUSED" 2 "1ST THRU 8TH GRADE"
                       3 "9TH THRU 11TH GRADE" 4 "12TH GRADE"
                       5 "TECHNICAL SCHOOL" 6 "1 THROUGH 3 YEARS COLLEGE"
                       7 "4 YEARS COLLEGE" 8 "GRADUATE / PROFESSIONAL SCHOOL" ;
label define A8_       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define A9_       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "BETTER THAN AVERAGE" 2 "AVERAGE" 3 "NOT SO GOOD" ;
label define A10_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define A11_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -1 "REFUSED"
                       1 "NEVER" 2 "LESS THAN ONCE A YEAR"
                       3 "ABOUT ONCE OR TWICE A YEAR"
                       4 "SEVERAL TIMES A YEAR" 5 "ABOUT ONCE A MONTH"
                       6 "TWO TO THREE TIMES A MONTH" 7 "NEARLY EVERY WEEK"
                       8 "EVERY WEEK" 9 "SEVERAL TIMES A WEEK" ;
label define A12_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "VERY IMPORTANT" 2 "IMPORTANT"
                       4 "NOT SO IMPORTANT" 5 "NOT AT ALL IMPORTANT" ;
label define A14_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 0 "0 MOVES" 1 "1 MOVES"
                       2 "2 OR MORE MOVES" ;
label define B1_       -3 "MISSING" 1 "YES" 2 "NO" ;
label define B2_       -3 "MISSING" -2 "DONT KNOW" 1 "UNDER 18" 2 "18-29"
                       3 "30-39" 4 "40-49" 5 "50-64" 6 "65 AND OLDER" ;
label define B3_       -3 "MISSING" 1 "YES" 2 "NO" ;
label define B4_       -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define B5_       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "UNDER 18" 2 "18-29" 3 "30-39" 4 "40-49" 5 "50-64"
                       6 "65 AND OLDER" ;
label define B6_       -3 "MISSING" 1 "YES" 2 "NO" ;
label define B7_       1 "YES" 2 "NO" ;
label define B8_       -3 "MISSING" -2 "DONT KNOW" 1 "UNDER 18" 2 "18-29"
                       3 "30-39" 4 "40-49" 5 "50-64" 6 "65 AND OLDER" ;
label define B9_       -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define B10_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define B11_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "UNDER 18" 2 "18-29" 3 "30-39" 4 "40-49" 5 "50-64"
                       6 "65 AND OLDER" ;
label define B12_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define B13_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define B14_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "UNDER 18" 2 "18-29" 3 "30-39" 4 "40-49" 5 "50-64"
                       6 "65 AND OLDER" ;
label define B15_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B16_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B17_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "UNDER 18" 2 "18-29" 3 "30-39" 4 "40-49" 5 "50-64" ;
label define B18_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B19_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B20_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "UNDER 18" 2 "18-29" 3 "30-39" 4 "40-49" 5 "50-64"
                       6 "65 AND OLDER" ;
label define B21_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B22_      -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define B23_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "UNDER 18" 2 "18-29" 3 "30-39" 4 "40-49" 5 "50-64"
                       6 "65 AND OLDER" ;
label define B24_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define B25_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -1 "REFUSED"
                       1 "YES" 2 "NO" ;
label define B26_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "UNDER 18" 2 "18-29" 3 "30-39" 4 "40-49" 5 "50-64"
                       6 "65 AND OLDER" ;
label define B27_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define B28_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B29_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B30_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B31_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B32_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define B33_      -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED"
                       1 "ABOUT EVERY DAY" 2 "ONE TO THREE TIMES A WEEK"
                       3 "ONCE OR TWICE A MONTH" 4 "A FEW DAYS ALL YEAR"
                       5 "ONLY ONE DAY IN THE PAST YEAR" ;
label define B34_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" ;
label define B35_      -3 "MISSING" 1 "NEVADA" 2 "IN ATLANTIC CITY"
                       3 "IN BILOXI/GULF COAST MISSISSIPPI"
                       5 "IN ANOTHER LOCATION" ;
label define B36_      -3 "MISSING" -2 "DONT KNOW" 1 "LESS THAN 10 MILES"
                       2 "BETWEEN 10 AND 50 MILES"
                       3 "MORE THAN 50 MILES BUT NOT MORE THAN 250"
                       4 "MORE THAN 250 MILES" ;
label define B37_      -3 "MISSING" 1 "LESS THAN TWO HOURS"
                       2 "TWO TO FOUR HOURS" 3 "FIVE TO TEN HOURS"
                       4 "MORE THAN TEN HOURS" ;
label define B38_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define B39_      -3 "MISSING" 1 "TABLE GAME" 2 "MACHINE" 3 "KENO TYPE"
                       4 "SPORTS"
                       5 "DOG/HORSE RACE BETTING (OFF-TRACK BETTIN" 6 "BINGO"
                       7 "PULL-TABS" 8 "OTHER (SPECIFY)" ;
label define B40_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define B41_      -3.0 "MISSING" -2.0 "DONT KNOW" -1.0 "REFUSED" ;
label define B42_      -3.0 "MISSING" -2.0 "DONT KNOW" -1.0 "REFUSED" ;
label define B43_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define B44_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define B44_2     -3 "MISSING" 1 "YES" 2 "NO" ;
label define B44_3     -3 "MISSING" 1 "YES" 2 "NO" ;
label define B44_4     -3 "MISSING" 1 "YES" 2 "NO" ;
label define B44_5     -3 "MISSING" 1 "YES" 2 "NO" ;
label define B44_6     -3 "MISSING" 1 "YES" 2 "NO" ;
label define B44_7     -3 "MISSING" 1 "YES" 2 "NO" ;
label define B45_      -3 "MISSING" 1 "IN THE PLACE WHERE YOU WERE GAMBLING"
                       2 "WITHIN WALKING DISTANCE OF WHERE YOU WER" ;
label define B46_      -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED" 1 "AHEAD"
                       2 "BEHIND" 3 "BROKE EVEN" ;
label define B47A_CD   -3 "MISSING" -1 "REFUSED" 1 "UNDER $100"
                       2 "$100 TO $500" 3 "$501 TO $1 000"
                       4 "$1 001 TO $5 000" 6 "$10 001 TO $50 000" ;
label define B47B_CD   -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED"
                       1 "UNDER $100" 2 "$100 TO $500" 3 "$501 TO $1 000"
                       4 "$1 001 TO $5 000" 5 "$5 001 TO $10 000" ;
label define B48_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define B49_      -3 "MISSING" 1 "TABLE GAME" 2 "MACHINE" 3 "KENO TYPE"
                       4 "SPORTS" 5 "DOG/HORSE RACE BETTING" 6 "BINGO"
                       8 "OTHER (SPECIFY)" ;
label define B50_      -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define B51_      -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED" 1 "AHEAD"
                       2 "BEHIND" 3 "BROKE EVEN" ;
label define B52A_CD   -3 "MISSING" 1 "UNDER $100" 2 "$100 TO $500"
                       3 "$501 TO $1 000" 4 "$1 001 TO $5 000"
                       5 "$5 001 TO $10 000" 6 "$10 001 TO $50 000"
                       7 "$50 001 TO $100 000" ;
label define B52B_CD   -3 "MISSING" -2 "DONT KNOW" 1 "UNDER $100"
                       2 "$100 TO $500" 3 "$501 TO $1 000"
                       4 "$1 001 TO $5 000" 5 "$5 001 TO $10 000"
                       6 "$10 001 TO $50 000" ;
label define B53_      -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define B54_      -3 "MISSING" 1 "ABOUT EVERY DAY"
                       2 "ONE TO THREE TIMES A WEEK"
                       3 "ONCE OR TWICE A MONTH" 4 "A FEW DAYS ALL YEAR"
                       5 "ONLY ONE DAY IN THE PAST YEAR" ;
label define B55_      -3 "MISSING"
                       1 "RACE TRACK (INCLUDE INTER-TRACK BETTING"
                       2 "HI-LIE FRAHN-TON" 3 "OTB" ;
label define B56_      -3 "MISSING" 1 "LESS THAN 10 MILES"
                       2 "BETWEEN 10 AND 50 MILES"
                       3 "MORE THAN 50 MILES BUT NOT MORE THAN 250"
                       4 "MORE THAN 250 MILES" ;
label define B57_      -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define B58_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define B59_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define B59_2     -3 "MISSING" 1 "YES" 2 "NO" ;
label define B59_3     -3 "MISSING" 1 "YES" 2 "NO" ;
label define B59_4     -3 "MISSING" 1 "YES" 2 "NO" ;
label define B59_5     -3 "MISSING" 2 "NO" ;
label define B59_6     -3 "MISSING" 1 "YES" 2 "NO" ;
label define B60_      -3 "MISSING" 1 "LESS THAN TWO HOURS"
                       2 "TWO TO FOUR HOURS" 3 "FIVE TO TEN HOURS"
                       4 "MORE THAN TEN HOURS" ;
label define B61_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define B62_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -1 "REFUSED" ;
label define B63_      -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED" ;
label define B64_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B65_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B65_2     -3 "MISSING" 1 "YES" 2 "NO" ;
label define B65_3     -3 "MISSING" 2 "NO" ;
label define B65_4     -3 "MISSING" 2 "NO" ;
label define B65_5     -3 "MISSING" 1 "YES" 2 "NO" ;
label define B66_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING"
                       2 "WITHIN WALKING DISTANCE OF WHERE YOU WER" ;
label define B67_      -3 "MISSING" -2 "DONT KNOW" 1 "AHEAD" 2 "BEHIND"
                       3 "BROKE EVEN" ;
label define B68A_CD   -3 "MISSING" 1 "UNDER $100" 2 "$100 TO $500"
                       3 "$501 TO $1 000" 4 "$1 001 TO $5 000" ;
label define B68B_CD   -3 "MISSING" 1 "UNDER $100" 2 "$100 TO $500"
                       3 "$501 TO $1 000" 4 "$1 001 TO $5 000" ;
label define B71_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "AHEAD"
                       2 "BEHIND" 3 "BROKE EVEN" ;
label define B72A_CD   -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100"
                       2 "$100 TO $500" 3 "$501 TO $1 000"
                       4 "$1 001 TO $5 000" 5 "$5 001 TO $10 000" ;
label define B72B_CD   -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100"
                       2 "$100 TO $500" 3 "$501 TO $1 000"
                       4 "$1 001 TO $5 000" ;
label define B73_      -3 "MISSING" -2 "DONT KNOW" 1 "ABOUT EVERY DAY"
                       2 "ONE TO THREE TIMES A WEEK"
                       3 "ONCE OR TWICE A MONTH" 4 "A FEW DAYS ALL YEAR"
                       5 "ONLY ONE DAY IN THE PAST YEAR" ;
label define B74_      -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED" 1 "YES"
                       2 "NO" ;
label define B75_      -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define B76_      -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define B77_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YOU"
                       2 "A RELATIVE" 3 "SOMEONE ELSE" ;
label define B78_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "SELF"
                       2 "PARENT" 5 "SOMEONE ELSE" ;
label define B79_      -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define B79_2     -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define B79_3     -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define B79_4     -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define B80_      -3 "MISSING" -2 "DONT KNOW" ;
label define B82_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define B84_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "LESS THAN (-2)A QUARTER OF THE MONEY"
                       2 "BETWEEN A QUARTER AND HALF OF THE MONEY"
                       3 "FROM HALF TO THREE QUARTERS"
                       4 "MORE THAN THREE QUARTERS" ;
label define B80_2     -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED" ;
label define B82_2     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define B84_2     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "LESS THAN A QUARTER OF THE MONEY"
                       2 "BETWEEN A QUARTER AND HALF OF THE MONEY"
                       3 "FROM HALF TO THREE QUARTERS"
                       4 "MORE THAN THREE QUARTERS" ;
label define B80_3     -3.0 "MISSING" -2.0 "DONT KNOW" ;
label define B82_3     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define B84_3     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "LESS THAN A QUARTER OF THE MONEY"
                       3 "FROM HALF TO THREE QUARTERS"
                       4 "MORE THAN THREE QUARTERS" ;
label define B80_4     -3 "MISSING" -2 "DONT KNOW" ;
label define B82_4     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B84_4     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "LESS THAN A QUARTER OF THE MONEY"
                       2 "BETWEEN A QUARTER AND HALF OF THE MONEY"
                       3 "FROM HALF TO THREE QUARTERS"
                       4 "MORE THAN THREE QUARTERS" ;
label define B85_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" 3 "DID NOT LIVE WITH ANYONE" ;
label define B86_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW" ;
label define B87_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define B88_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "TWO OR THREE" 2 "FOUR TO TEN" 3 "ELEVEN TO TWENTY"
                       4 "MORE THAN TWENTY" ;
label define B89_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B89_2     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B89_3     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B89_4     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B90A_     -3 "MISSING" -2 "DONT KNOW" 1 "MULTI-STATE"
                       2 "OTHER BIG JACKPOT" 3 "DAILY"
                       4 "INSTANT/SCRATCH-OFF" 5 "NO FAVORITE" ;
label define B91_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "A QUARTER OR LESS OF EVERY DOLLAR" 2 "ABOUT HALF"
                       3 "THREE-QUARTERS OR MORE" ;
label define B92_      -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED" 1 "AHEAD"
                       2 "BEHIND" 3 "BROKE EVEN" ;
label define B93A_CD   -3 "MISSING" 1 "UNDER $100" 2 "$100 TO $500"
                       3 "$501 TO $1 000" 4 "$1 001 TO $5 000"
                       5 "$5 001 TO $10 000" 6 "$10 001 TO $50 000" ;
label define B93B_CD   -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED"
                       1 "UNDER $100" 2 "$100 TO $500" 3 "$501 TO $1 000"
                       4 "$1 001 TO $5 000" 5 "$5 001 TO $10 000"
                       6 "$10 001 TO $50 000" ;
label define B94_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       2 "ONE TO THREE TIMES A WEEK"
                       3 "ONCE OR TWICE A MONTH" 4 "A FEW DAYS ALL YEAR"
                       5 "ONLY ONE DAY IN THE PAST YEAR" ;
label define B95_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B96_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "LESS THAN TWO HOURS" 2 "TWO TO FOUR HOURS"
                       3 "FIVE TO TEN HOURS" 4 "MORE THAN TEN HOURS" ;
label define B97_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "LESS THAN 10 MILES" 2 "BETWEEN 10 AND 50 MILES"
                       3 "MORE THAN 50 MILES BUT NOT MORE THAN 25"
                       4 "MORE THAN 250 MILES" ;
label define B98_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define B99_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW" ;
label define B100_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" ;
label define B101_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B102_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B102_2    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B102_3    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B102_4    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B102_5    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B102_6    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B103_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING"
                       1 "IN THE PLACE YOU WERE GAMBLING?"
                       2 "WITHIN WALKING DISTANCE OF WHERE YOU WERE"
                       3 "WOULD SOMEONE HAVE TO DRIVE TO GET THERE?" ;
label define B104_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "AHEAD"
                       2 "BEHIND" 3 "BROKE EVEN" ;
label define B105A_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100"
                       2 "$100 TO $500" 3 "$501 TO $1 000"
                       4 "$1 001 TO $5 000" 5 "$5 001 TO $10 000" ;
label define B105B_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100" ;
label define B106_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B107_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "AHEAD" 2 "BEHIND" 3 "BROKE EVEN" ;
label define B108A_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100"
                       2 "$100 TO $500" 3 "$501 TO $1 000"
                       4 "$1 001 TO $5 000" 5 "$5 001 TO $10 000" ;
label define B108B_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "UNDER $100" 2 "$100 TO $500" 3 "$501 TO $1 000" ;
label define B109_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       2 "ONE TO THREE TIMES A WEEK"
                       3 "ONCE OR TWICE A MONTH" 4 "A FEW DAYS ALL YEAR"
                       5 "ONLY ONE DAY IN THE PAST YEAR" ;
label define B110_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B111_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "LESS THAN TWO HOURS" 2 "TWO TO FOUR HOURS" ;
label define B112_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "LESS THAN 10 MILES" 2 "BETWEEN 10 AND 50 MILES"
                       3 "MORE THAN 50 MILES BUT NOT MORE THAN 250"
                       4 "MORE THAN 250 MILES" ;
label define B114_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define B115_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW" ;
label define B116_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW" ;
label define B117_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define B118_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B118_2    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B118_3    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B118_4    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B118_5    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" ;
label define B118_6    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B119_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" ;
label define B120_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "AHEAD" 2 "BEHIND" 3 "BROKE EVEN" ;
label define B121A_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100"
                       2 "$100 TO $500" 3 "$501 TO $1 000" ;
label define B121B_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100"
                       2 "$100 TO $500" ;
label define B122_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B123_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "AHEAD" 2 "BEHIND" 3 "BROKE EVEN" ;
label define B124A_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100"
                       2 "$100 TO $500" 3 "$501 TO $1 000" ;
label define B124B_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100"
                       2 "$100 TO $500" 3 "$501 TO $1 000" ;
label define B125_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "ABOUT EVERY DAY"
                       2 "ONE TO THREE TIMES A WEEK"
                       3 "ONCE OR TWICE A MONTH" 4 "A FEW DAYS ALL YEAR"
                       5 "ONLY ONE DAY IN THE PAST YEAR" ;
label define B126_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define B127_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "LESS THAN TWO HOURS"
                       2 "TWO TO FOUR HOURS" 3 "FIVE TO TEN HOURS"
                       4 "MORE THAN TEN HOURS" ;
label define B128_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "LESS THAN 10 MILES"
                       2 "BETWEEN 10 AND 50 MILES"
                       3 "MORE THAN 50 MILES BUT NOT MORE THAN 250"
                       4 "MORE THAN 250 MILES" ;
label define B129_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define B130_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" ;
label define B131_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" ;
label define B132_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define B133_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B133_2    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" ;
label define B133_3    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B133_4    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B133_5    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B133_6    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B133_7    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B134_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING"
                       1 "IN THE PLACE WHERE YOU WERE GAMBLING"
                       3 "WOULD SOMEONE HAVE TO DRIVE TO GET THERE" ;
label define B135_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "AHEAD" 2 "BEHIND" 3 "BROKE EVEN" ;
label define B136A_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100"
                       2 "$100 TO $500" ;
label define B136B_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100"
                       2 "$100 TO $500" ;
label define B137_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define B138_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "AHEAD" 2 "BEHIND" 3 "BROKE EVEN" ;
label define B139A_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100"
                       2 "$100 TO $500" 3 "$501 TO $1 000"
                       4 "$1 001 TO $5 000" ;
label define B139B_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100"
                       2 "$100 TO $500" 3 "$501 TO $1 000" ;
label define B140_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "ABOUT EVERY DAY" 2 "ONE TO THREE TIMES A WEEK"
                       3 "ONCE OR TWICE A MONTH" 4 "A FEW DAYS ALL YEAR"
                       5 "ONLY ONE DAY IN THE PAST YEAR" ;
label define B141_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING"
                       1 "LESS THAN TWO HOURS" 2 "TWO TO FOUR HOURS"
                       3 "FIVE TO TEN HOURS" 4 "MORE THAN TEN HOURS" ;
label define B142_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "AHEAD" 2 "BEHIND" 3 "BROKE EVEN" ;
label define B143A_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100"
                       2 "$100 TO $500" 3 "$501 TO $1 000"
                       4 "$1 001 TO $5 000" ;
label define B143B_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100"
                       2 "$100 TO $500" ;
label define B144_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "AHEAD" 2 "BEHIND" 3 "BROKE EVEN" ;
label define B145A_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100"
                       2 "$100 TO $500" 3 "$501 TO $1 000"
                       4 "$1 001 TO $5 000" 6 "$10 001 TO $50 000" ;
label define B145B_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "UNDER $100" 2 "$100 TO $500" ;
label define B146_     -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED"
                       1 "ABOUT EVERY DAY" 2 "ONE TO THREE TIMES A WEEK"
                       3 "ONCE OR TWICE A MONTH" 4 "A FEW DAYS ALL YEAR"
                       5 "ONLY ONE DAY IN THE PAST YEAR" ;
label define B147_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define B148_     -3 "MISSING" -2 "DONT KNOW" 1 "A BAR OR RESTAURANT"
                       2 "A TRUCK STOP OR GAS STATION"
                       3 "A CONVENIENCE STORE" 4 "A SUPERMARKET"
                       5 "SOMEPLACE ELSE" ;
label define B149_     -3 "MISSING" -2 "DONT KNOW" 1 "LESS THAN 10 MILES"
                       2 "BETWEEN 10 AND 50 MILES"
                       3 "MORE THAN 50 MILES BUT NOT MORE THAN 250"
                       4 "MORE THAN 250 MILES" ;
label define B150_     -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define B150_2    -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define B150_3    -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define B150_4    -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define B150_5    -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define B151_     -3 "MISSING" -2 "DONT KNOW" 1 "LESS THAN TWO HOURS"
                       2 "TWO TO FOUR HOURS" 3 "FIVE TO TEN HOURS"
                       4 "MORE THAN TEN HOURS" ;
label define B152_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define B153_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" ;
label define B154_     -3 "MISSING" -2 "DONT KNOW" ;
label define B155_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define B156_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" ;
label define B156_2    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B156_3    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B156_4    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B156_5    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B156_6    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B156_7    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define B157_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" ;
label define B158_     -3 "MISSING" -2 "DONT KNOW" 1 "AHEAD" 2 "BEHIND"
                       3 "BROKE EVEN" ;
label define B159A_CD  -3 "MISSING" 1 "UNDER $100" 2 "$100 TO $500" ;
label define B159B_CD  -3 "MISSING" 1 "UNDER $100" 2 "$100 TO $500"
                       4 "$1 001 TO $5 000" 5 "$5 001 TO $10 000" ;
label define B160_     -3 "MISSING" 1 "YES" 2 "NO" ;
label define B161_     -3 "MISSING" 1 "SLOT MACHINES"
                       2 "A VIDEO LOTTERY MACHINE"
                       3 "SOME OTHER KIND OF ELECTRONIC GAME" 4 "PULL TABS"
                       5 "SOMETHING ELSE" ;
label define B162_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define B163_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "AHEAD" 2 "BEHIND" 3 "BROKE EVEN" ;
label define B164A_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100"
                       2 "$100 TO $500" 3 "$501 TO $1 000"
                       4 "$1 001 TO $5 000" 6 "$10 001 TO $50 000" ;
label define B164B_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "UNDER $100" 2 "$100 TO $500" 4 "$1 001 TO $5 000" ;
label define B165_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "ABOUT EVERY DAY" 2 "ONE TO THREE TIMES A WEEK"
                       3 "ONCE OR TWICE A MONTH" 4 "A FEW DAYS ALL YEAR"
                       5 "ONLY ONE DAY IN THE PAST YEAR" ;
label define B166_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "PARTICIPATED IN A SPORTS POOL"
                       2 "PLACED A BET WITH A BOOKMAKER"
                       3 "BOUGHT A POLICY OR PLAYED NONLICENSED NU" 5 "OTHER" ;
label define B167_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "LESS THAN 10 MILES" ;
label define B168_     -9.0 "PATRON:LOGIC. MISSING" -3.0 "MISSING"
                       -2.0 "DONT KNOW" -1.0 "REFUSED" ;
label define B169_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "AHEAD" 2 "BEHIND" 3 "BROKE EVEN" ;
label define B170A_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100"
                       2 "$100 TO $500" 4 "$1 001 TO $5 000"
                       6 "$10 001 TO $50 000" ;
label define B170B_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "UNDER $100" 2 "$100 TO $500" ;
label define B171_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       3 "ONCE OR TWICE A MONTH" 4 "A FEW DAYS ALL YEAR" ;
label define B172_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "LESS THAN TWO HOURS" 3 "FIVE TO TEN HOURS" ;
label define B173_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define B174_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" ;
label define B175_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "AHEAD" 2 "BEHIND" 3 "BROKE EVEN" ;
label define B176A_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100"
                       2 "$100 TO $500" ;
label define B176B_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100"
                       2 "$100 TO $500" ;
label define B177_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "AHEAD" 2 "BEHIND" 3 "BROKE EVEN" ;
label define B178A_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING"
                       2 "$100 TO $500" ;
label define B178B_CD  -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "UNDER $100"
                       2 "$100 TO $500" ;
label define C1_       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "VERY GOOD" 2 "GOOD"
                       3 "ABOUT EQUALLY GOOD AND BAD" 4 "BAD" 5 "VERY BAD" ;
label define C2_       -9 "PATRON:LOGIC. MISSING" -3 "MISSING"
                       1 "HAS NOT GAMBLED IN PAST YEAR" ;
label define C3_       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "VERY IMPORTANT" 2 "IMPORTANT" 3 "NOT SO IMPORTANT"
                       4 "NOT AT ALL IMPORTANT" ;
label define C4_       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "VERY IMPORTANT" 2 "IMPORTANT"
                       3 "NOT SO IMPORTANT" 4 "NOT AT ALL IMPORTANT" ;
label define C5_       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "VERY IMPORTANT" 2 "IMPORTANT" 3 "NOT SO IMPORTANT"
                       4 "NOT AT ALL IMPORTANT" ;
label define C6_       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define C8_       -3 "MISSING" 1 "HAS NOT GAMBLED IN PAST YEAR" ;
label define C9_       -3 "MISSING" -2 "DONT KNOW" 1 "VERY IMPORTANT"
                       2 "IMPORTANT" 3 "NOT SO IMPORTANT"
                       4 "NOT AT ALL IMPORTANT" ;
label define C10_      -3 "MISSING" -2 "DONT KNOW" 1 "VERY IMPORTANT"
                       2 "IMPORTANT" 3 "NOT SO IMPORTANT"
                       4 "NOT AT ALL IMPORTANT" ;
label define C11_      -3 "MISSING" -2 "DONT KNOW" 1 "VERY IMPORTANT"
                       2 "IMPORTANT" 3 "NOT SO IMPORTANT"
                       4 "NOT AT ALL IMPORTANT" ;
label define C12_      -3 "MISSING" -2 "DONT KNOW" 1 "VERY IMPORTANT"
                       2 "IMPORTANT" 3 "NOT SO IMPORTANT"
                       4 "NOT AT ALL IMPORTANT" ;
label define C13_      -3 "MISSING" 1 "VERY IMPORTANT" 2 "IMPORTANT"
                       3 "NOT SO IMPORTANT" 4 "NOT AT ALL IMPORTANT" ;
label define C14_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define C15_      -3 "MISSING" -1 "REFUSED" 1 "BINGO"
                       2 "BOOK-TYPE BETTING" 3 "CARD GAMES"
                       4 "CHARITABLE GAMES" 5 "DICE" 6 "GAMES OF SKILL"
                       7 "INSTANT LOTTERY GAMES" 8 "INTERNET/WWW GAMBLING"
                       9 "LIVE KENO" 10 "OFF-TRACK BETTING"
                       11 "LOTTERY GAMES (NOT INSTANT)"
                       12 "OUTCOME OF SPORTS EVENTS W/ ACQ"
                       13 "PARI-MUTUEL SPORTS" 14 "PULL-TABS" 15 "ROULETTE"
                       16 "SLOT MACHINES" 17 "SPORTS POOLS"
                       18 "TABLE GAMES (IN GENERAL)" 19 "VIDEO MACHINE GAMES"
                       20 "OTHER (SPECIFY)" 21 "NO FAVORITE" ;
label define C16_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define C17_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YOUR SPOUSE OR PARTNER" 2 "OTHER FAMILY MEMBER(S)"
                       3 "FRIEND(S) CO-WORKER(S) NEIGHBOR(S) CL"
                       4 "SOME OTHER INDIVIDUAL OR GROUP" ;
label define C18_CD    -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED" 1 "NONE"
                       2 "UNDER $100" 3 "$100 TO $500" 4 "$501 TO $1 000"
                       5 "$1 001 TO $5 000" 6 "$5 001 TO $10 000"
                       7 "$10 001 TO $50 000" 8 "$50 001 TO $100 000"
                       9 "$100 001 TO $1 MILLION" ;
label define C19_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define C20_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "SAVE" 2 "SPEND" ;
label define C21_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "PARTICULAR" 2 "GENERAL" ;
label define C22_CD    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define C22_CD2   -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED" 1 "YES"
                       2 "NO" ;
label define C22_CD3   -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED" 1 "YES"
                       2 "NO" ;
label define C22_CD4   -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED" 1 "YES"
                       2 "NO" ;
label define C22_CD5   -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED" 1 "YES"
                       2 "NO" ;
label define C23_CD    -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED"
                       1 "NEVER LOST ANY MONEY" 2 "UNDER $100"
                       3 "$100 TO $500" 4 "$501 TO $1 000"
                       5 "$1 001 TO $5 000" 6 "$5 001 TO $10 000"
                       7 "$10 001 TO $50 000" ;
label define C24_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define C25_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING"
                       1 "CASH ON HAND" 2 "BORROW OR CREDIT" ;
label define C26_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "GAMBLE" 2 "SAVE" 3 "SPEND" ;
label define C27_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "PARTICULAR" 2 "GENERAL" ;
label define C28_CD    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define C28_CD2   -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define C28_CD3   -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define C28_CD4   -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define C28_CD5   -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define C29_CD    -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "NEVER LOST MONEY" 2 "UNDER $100"
                       3 "$100 TO $500" 4 "$501 TO $1 000"
                       5 "$1 001 TO $5 000" 6 "$5 001 TO $10 000" ;
label define D1_       -3 "MISSING" 1 "YES" 2 "NO" ;
label define D2_       -3 "MISSING" 1 "YES" 2 "NO" ;
label define D3_       -3 "MISSING" 1 "YES" 2 "NO" ;
label define D4_       -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define D5_       -3 "MISSING" 1 "YES" 2 "NO" ;
label define D6_       -3 "MISSING" 1 "YES" 2 "NO" ;
label define D7_       -3 "MISSING" 1 "YES" 2 "NO" ;
label define D8_       -3 "MISSING" 1 "YES" 2 "NO" ;
label define D9_       -3 "MISSING" 1 "YES" 2 "NO" ;
label define D10_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D11_      -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED" 1 "YES"
                       2 "NO" ;
label define D12_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D13_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D14_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D15_      -3 "MISSING" 2 "NO" ;
label define D16_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D17_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D18_      -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define D19_      -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define D20_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D21_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D22_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D23_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D24_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D25_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D26_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D27_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D28_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D29_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D30_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D31_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D32_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D33_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D34_      -3 "MISSING" ;
label define D35_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define D36_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define E1_       -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define E2_       -3 "MISSING" 1 "YES" 2 "NO" ;
label define E2_2      -3 "MISSING" 1 "YES" 2 "NO" ;
label define E2_3      -3 "MISSING" 1 "YES" 2 "NO" ;
label define E2_4      -3 "MISSING" 1 "YES" 2 "NO" ;
label define E2_5      -3 "MISSING" 1 "YES" 2 "NO" ;
label define E2_6      -3 "MISSING" 1 "YES" 2 "NO" ;
label define E3_       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" ;
label define E4_       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define E5_       -3 "MISSING" 1 "YES" 2 "NO" ;
label define E6_       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" ;
label define E7_       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define F1_       -2 "DONT KNOW" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define F2_       -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define F3_       -3 "MISSING" -1 "REFUSED" 1 "TOGETHER" 2 "SEPARATED" ;
label define F4_       -3 "MISSING" -1 "REFUSED" 1 "ONCE" 2 "TWICE"
                       3 "THREE OR MORE TIMES" ;
label define F5_       -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define F6_       -3 "MISSING" 1 "YES" 2 "NO" ;
label define F7_       -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define F8_       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define F10_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define F11_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define F12_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" ;
label define F13_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" ;
label define F14_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define F16A_     -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define F16B_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -1 "REFUSED"
                       1 "YES" 2 "NO" ;
label define F16C_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -1 "REFUSED"
                       1 "YES" 2 "NO" ;
label define F16D_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -1 "REFUSED"
                       1 "YES" 2 "NO" ;
label define F16E_     -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define F16F_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -1 "REFUSED"
                       1 "YES" 2 "NO" ;
label define F16G_     -3 "MISSING" 1 "YES" 2 "NO" ;
label define F17_      -3 "MISSING" -1 "REFUSED" 3 "3 OR MORE" ;
label define F19_      -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define F20_      -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define F20_2     -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define F20_3     -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define F20_4     -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define F20_5     -3 "MISSING" -1 "REFUSED" 2 "NO" ;
label define F20_6     -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define F20_7     -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define F21_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define F22_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define F23_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define F23_2     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define F23_3     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define F23_4     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define F23_5     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define F23_6     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define F23_7     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define F24_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define F25_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define F25_2     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define F25_3     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define F25_4     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define F25_5     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define F25_6     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define F25_7     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define F26_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define F27_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define G1_       -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED"
                       1 "WORKING FULL-TIME WITH ONLY ONE JOB"
                       2 "WORKING A FULL-TIME JOB PLUS ANOTHER JO"
                       3 "WORKING PART-TIME WITH ONLY ONE JOB"
                       4 "WORKING MORE THAN ONE PART-TIME JOB"
                       5 "ARE YOU UNEMPLOYED OR NOT IN THE LABOR" ;
label define G2A_      -3 "MISSING" -1 "REFUSED" 10 "CLERICAL WORKER"
                       20 "SALES WORKER" 30 "SERVICE WORKER"
                       40 "PRIVATE HOUSEHOLD WORKER"
                       50 "SKILLED WORKER OR CRAFTSMAN" 60 "LABORER"
                       70 "OPERATOR OR MACHINE OPERATOR"
                       80 "TRANSPORTATION EQUIPMENT OPERATOR"
                       90 "FARM LABORER" 100 "FARMER OR FARM MANAGER"
                       110 "MANAGER/ADMINISTRATOR" 120 "LAY COUNSELOR"
                       130 "PROFESSIONAL/TECHNICAL" 140 "OTHER"
                       144 "GAMBLING JOB LEGAL"
                       150 "INTERVIEWER UNABLE TO CODE" ;
label define G3A_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING"
                       10 "CLERICAL WORKER" 20 "SALES WORKER"
                       30 "SERVICE WORKER" 40 "PRIVATE HOUSEHOLD WORKER"
                       50 "SKILLED WORKER OR CRAFTSMAN" 60 "LABORER"
                       80 "TRANSPORTATION EQUIPMENT OPERATOR"
                       90 "FARM LABORER" 100 "FARMER OR FARM MANAGER"
                       110 "MANAGER/ADMINISTRATOR"
                       130 "PROFESSIONAL/TECHNICAL" 140 "OTHER"
                       150 "INTERVIEWER UNABLE TO CODE" ;
label define G4_       -3 "MISSING" -1 "REFUSED" 1 "LESS THAN ONE MONTH"
                       2 "1 - 12 MONTHS" 3 "MORE THAN 12 MONTHS" ;
label define G5_       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "UP TO 10 DOLLARS PER HOUR"
                       2 "BETWEEN 10 AND 25 DOLLARS PER HOUR"
                       3 "BETWEEN 25 AND 50 DOLLARS PER HOUR"
                       4 "MORE THAN 50 DOLLARS PER HOUR" ;
label define G6_       -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED" 1 "NONE"
                       2 "LESS THAN ONE MONTH" 3 "1 - 3 MONTHS"
                       4 "4 - 6 MONTHS" 5 "7 - 9 MONTHS" 6 "10 - 12 MONTHS" ;
label define G7_       -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED"
                       1 "INCOME REPORTED" 2 "INCOME NOT REPORTED" ;
label define G8_       -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define G9_       -3 "MISSING" 1 "ONE TO TWO DAYS" 2 "THREE TO SIX DAYS"
                       3 "ONE TO TWO WEEKS" 4 "TWO TO THREE WEEKS"
                       5 "MORE THAN 3 WEEKS" ;
label define G12_      -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define G13_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define G14_      -3 "MISSING" 1 "YES" ;
label define G16_      -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define G17_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define G17_2     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define G17_3     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define G17_4     -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED" 1 "YES"
                       2 "NO" ;
label define G17_5     -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED" 1 "YES"
                       2 "NO" ;
label define G17_6     -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED" 1 "YES"
                       2 "NO" ;
label define G17_7     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define G17_8     -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED" 1 "YES"
                       2 "NO" ;
label define G18_      -9 "PATRON:LOGIC. MISSING" -2 "DONT KNOW"
                       1 "VALUE PRESENT" 2 "VALUE MISSING" ;
label define G18_2     -9 "PATRON:LOGIC. MISSING" -2 "DONT KNOW" -1 "REFUSED"
                       1 "VALUE PRESENT" 2 "VALUE MISSING" ;
label define G18_3     -9 "PATRON:LOGIC. MISSING" -2 "DONT KNOW" -1 "REFUSED"
                       1 "VALUE PRESENT" 2 "VALUE MISSING" ;
label define G18_4     -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED"
                       1 "VALUE PRESENT" 2 "VALUE MISSING" ;
label define G18_5     -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED"
                       1 "VALUE PRESENT" 2 "VALUE MISSING" ;
label define G18_6     -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED"
                       1 "VALUE PRESENT" 2 "VALUE MISSING" ;
label define G18_7     -9 "PATRON:LOGIC. MISSING" -2 "DONT KNOW" -1 "REFUSED"
                       1 "VALUE PRESENT" 2 "VALUE MISSING" ;
label define G19_      -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED" 1 "ONE"
                       2 "TWO" 3 "THREE" 4 "FOUR TO SIX" 5 "SEVEN TO NINE"
                       6 "TEN OR MORE" ;
label define G20_      -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED"
                       1 "LESS THAN $10 000" 2 "$10 000 - $24 000"
                       3 "$25 000 - $49 000" 4 "$50 000 - $99 000"
                       5 "$100 000 - $200 000" 6 "MORE THAN $200 000" ;
label define G21_      -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED"
                       1 "LESS THAN $500" 2 "BETWEEN $500 AND $1 000"
                       3 "BETWEEN $1 000 AND $2 000" 4 "MORE THAN $2 000" ;
label define G22_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "SELECT TO RECORD AMOUNT SPENT"
                       2 "SELECT TO RECORD AMOUNT AHEAD"
                       3 "NO ONE IN HOUSEHOLD GAMBLES" ;
label define G22A_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" ;
label define G22B_     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" ;
label define G23_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "LESS THAN $1 000" 2 "$1 000 - $9 000"
                       3 "$10 000 - $24 000" 4 "$25 000 - $49 000"
                       5 "$50 000 - $99 000" 6 "$100 000 - $200 000"
                       7 "MORE THAN $200 000" 8 "DONT OWE ANY MONEY" ;
label define G24_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define G24_2     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define G24_3     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define G24_4     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define G24_5     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define G25_      -3 "MISSING" -2 "DONT KNOW" 1 "YES" 2 "NO" ;
label define G26_      -3 "MISSING" 1 "OWN" 2 "ANOTHER FAMILY MEMBERS"
                       3 "BOTH" ;
label define G27_      -3 "MISSING" 1 "LESS THAN HALF" 2 "ABOUT HALF"
                       3 "MORE THAN HALF" 4 "ALL OF THE MONEY" ;
label define G28_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define G29_      -3 "MISSING" 1 "LESS THAN $1 000" 2 "$1 000 - $9 000"
                       3 "$10 000 - $24 000" ;
label define G35_      -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define G36_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define G37_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "CHAPTER 7 (PERSONAL)"
                       2 "CHAPTER 13 (PERSONAL CONSOLIDATION OF D"
                       3 "CHAPTER 11 (BUSINESS)" ;
label define G38_      -3 "MISSING" 2 "NO" ;
label define G39_      -3 "MISSING" ;
label define G41_      -3 "MISSING" ;
label define H1A       -9 "PATRON:LOGIC. MISSING" -3 "MISSING"
                       1 "LESS THAN $100" 2 "$100 TO $500" ;
label define H2        -3 "MISSING" -2 "DONT KNOW" -1 "REFUSED" 1 "YES"
                       2 "NO" ;
label define H3        -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW" ;
label define H4        -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "UNDER 18" 2 "18-29" 3 "30-39" 4 "40-49" 5 "50-64"
                       6 "65 AND OLDER" ;
label define H5        -3 "MISSING" 1 "YES" 2 "NO" ;
label define H6        -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define H7        -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define H8        -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" ;
label define H10       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -1 "REFUSED"
                       1 "YES" 2 "NO" ;
label define H11       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define H12       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define H15       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" ;
label define H16       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define J1        -2 "DONT KNOW" -1 "REFUSED" 1 "EXCELLENT" 2 "GOOD"
                       3 "FAIR" 4 "POOR" ;
label define J2        -2 "DONT KNOW" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J3        -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "NOT AT ALL" 2 "SOMEWHAT" 3 "VERY MUCH" ;
label define J4        -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J5        -3 "MISSING" 1 "YES" 2 "NO" ;
label define J6        -3 "MISSING" 1 "YES" 2 "NO" ;
label define J7        -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J8        -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J9        -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J23       -2 "DONT KNOW" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J24       -2 "DONT KNOW" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J25       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J26       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J27       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J28       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define J29       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J30       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define J31       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J32       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define J33       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J34       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J35       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J36       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J37       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J38       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J39       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J40       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J41       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define J42       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define J43       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define J44       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define J45       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" ;
label define J47       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J48       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -1 "REFUSED"
                       1 "YES" 2 "NO" ;
label define J49       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -1 "REFUSED"
                       1 "YES" 2 "NO" ;
label define J50       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define J51       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       1 "YES" 2 "NO" ;
label define J52       -3 "MISSING" 1 "YES" 2 "NO" ;
label define J53       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define J55       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 3 "3 OR MORE" ;
label define J56       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -1 "REFUSED"
                       1 "ALL" 2 "SOME" 3 "NONE" ;
label define J57       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -1 "REFUSED"
                       1 "ALL" 2 "SOME" 3 "NONE" ;
label define J58       -3 "MISSING" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define J59       -3 "MISSING" 1 "YES" 2 "NO" ;
label define K1_       -2 "DONT KNOW" -1 "REFUSED" 1 "YES" 2 "NO" ;
label define K2_       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define K3_       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define K4_       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define K5_       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define K6_       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K7_       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -1 "REFUSED"
                       1 "YES" 2 "NO" ;
label define K8_       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K9_       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K10_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K11_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -1 "REFUSED"
                       1 "YES" 2 "NO" ;
label define K12_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -1 "REFUSED"
                       1 "YES" 2 "NO" ;
label define K13_      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" -2 "DONT KNOW"
                       -1 "REFUSED" 1 "YES" 2 "NO" ;
label define K6_2      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K7_2      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K8_2      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K9_2      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K10_2     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K11_2     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K12_2     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K13_2     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K6_3      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K7_3      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K8_3      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K9_3      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K10_3     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K11_3     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define K12_3     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K13_3     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K6_4      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K7_4      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K8_4      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K9_4      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define K10_4     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K11_4     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K12_4     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K13_4     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K6_5      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define K7_5      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K8_5      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K9_5      -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K10_5     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K11_5     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 2 "NO" ;
label define K12_5     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define K13_5     -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" 2 "NO" ;
label define CK1       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" ;
label define CK2       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" ;
label define CK3       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" ;
label define CK4       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" ;
label define CK5       -9 "PATRON:LOGIC. MISSING" -3 "MISSING" 1 "YES" ;
label define K14_      -3 "NOT ASKED" 1 "YES" 2 "NO" ;
label define K15_      -3 "MISSING" 1 "YES" 2 "NO" ;
label define SURVEY    1 "RANDOM DIGIT DIAL SAMPLE" 2 "PATRON PLAYER SAMPLE"
                       3 "PATRON NONPLAYER SAMPLE" ;
label define WTPOP     -3.0000 "MISSING" ;
label define WTSAMP    -3.0000 "MISSING" ;
label define RDDWGT    -3.0000 "MISSING" ;
label define LOTSTATE  -3 "MISSING" 1 "YES" 2 "NO" ;
label define INCOME    -3 "MISSING" 1 "LESS THAN $24,000" 2 "$24,000-$49,999"
                       3 "$50,000-$99,999" 4 "MORE THAN $100,000" ;
label define IINCOME   0 "NO IMPUTATION" 1 "IMPUTED VALUE FOR INCOME" ;
label define MARITAL   -3 "MISSING" 1 "MARRIED" 2 "DIVORCED/SEPARATED"
                       3 "NEVER MARRIED" 4 "COHABITING" 5 "WIDOWED" ;
label define RACETH    -3 "MISSING" 1 "WHITE" 2 "BLACK" 3 "HISPANIC"
                       4 "OTHER" ;
label define A2_R      -3 "MISSING" 1 "18-29" 2 "30-39" 3 "40-49" 4 "50-64"
                       5 "65 AND OLDER" ;
label define A4_R      -3 "MISSING" 1 "BLACK OR AFRICAN AMERICAN" 2 "WHITE"
                       3 "OTHER" ;
label define A6_R      -3 "MISSING" 1 "COLLEGE OR UNIVERSITY" 2 "OTHER" ;
label define SMSREG    -3 "MISSING" 1 "MIDWEST" 2 "NORTHEAST" 3 "SOUTH"
                       4 "WEST" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.\n
****************************************************************/

/*
replace CASEID = . if (CASEID <= -1 )
replace SU_ID = . if (SU_ID <= -1 )
replace A1_ = . if (A1_ <= -1 )
replace A3_ = . if (A3_ <= -1 )
replace A5_ = . if (A5_ <= -1 )
replace A7_ = . if (A7_ <= -1 )
replace A8_ = . if (A8_ <= -1 )
replace A9_ = . if (A9_ <= -1 )
replace A10_ = . if (A10_ <= -1 )
replace A11_ = . if (A11_ <= -1 )
replace A12_ = . if (A12_ <= -1 )
replace A14_ = . if (A14_ <= -1 )
replace B1_ = . if (B1_ <= -1 )
replace B2_ = . if (B2_ <= -1 )
replace B3_ = . if (B3_ <= -1 )
replace B4_ = . if (B4_ <= -1 )
replace B5_ = . if (B5_ <= -1 )
replace B6_ = . if (B6_ <= -1 )
replace B7_ = . if (B7_ <= -1 )
replace B8_ = . if (B8_ <= -1 )
replace B9_ = . if (B9_ <= -1 )
replace B10_ = . if (B10_ <= -1 )
replace B11_ = . if (B11_ <= -1 )
replace B12_ = . if (B12_ <= -1 )
replace B13_ = . if (B13_ <= -1 )
replace B14_ = . if (B14_ <= -1 )
replace B15_ = . if (B15_ <= -1 )
replace B16_ = . if (B16_ <= -1 )
replace B17_ = . if (B17_ <= -1 )
replace B18_ = . if (B18_ <= -1 )
replace B19_ = . if (B19_ <= -1 )
replace B20_ = . if (B20_ <= -1 )
replace B21_ = . if (B21_ <= -1 )
replace B22_ = . if (B22_ <= -1 )
replace B23_ = . if (B23_ <= -1 )
replace B24_ = . if (B24_ <= -1 )
replace B25_ = . if (B25_ <= -1 )
replace B26_ = . if (B26_ <= -1 )
replace B27_ = . if (B27_ <= -1 )
replace B28_ = . if (B28_ <= -1 )
replace B29_ = . if (B29_ <= -1 )
replace B30_ = . if (B30_ <= -1 )
replace B31_ = . if (B31_ <= -1 )
replace B32_ = . if (B32_ <= -1 )
replace B33_ = . if (B33_ <= -1 )
replace B34_ = . if (B34_ <= -1 )
replace B35_ = . if (B35_ <= -1 )
replace B36_ = . if (B36_ <= -1 )
replace B37_ = . if (B37_ <= -1 )
replace B38_ = . if (B38_ <= -1 )
replace B39_ = . if (B39_ <= -1 )
replace B40_ = . if (B40_ <= -1 )
replace B41_ = . if (B41_ <= -1.0 )
replace B42_ = . if (B42_ <= -1.0 )
replace B43_ = . if (B43_ <= -1 )
replace B44_ = . if (B44_ <= -1 )
replace B44_2 = . if (B44_2 <= -1 )
replace B44_3 = . if (B44_3 <= -1 )
replace B44_4 = . if (B44_4 <= -1 )
replace B44_5 = . if (B44_5 <= -1 )
replace B44_6 = . if (B44_6 <= -1 )
replace B44_7 = . if (B44_7 <= -1 )
replace B45_ = . if (B45_ <= -1 )
replace B46_ = . if (B46_ <= -1 )
replace B47A_CD = . if (B47A_CD <= -1 )
replace B47B_CD = . if (B47B_CD <= -1 )
replace B48_ = . if (B48_ <= -1 )
replace B49_ = . if (B49_ <= -1 )
replace B50_ = . if (B50_ <= -1 )
replace B51_ = . if (B51_ <= -1 )
replace B52A_CD = . if (B52A_CD <= -1 )
replace B52B_CD = . if (B52B_CD <= -1 )
replace B53_ = . if (B53_ <= -1 )
replace B54_ = . if (B54_ <= -1 )
replace B55_ = . if (B55_ <= -1 )
replace B56_ = . if (B56_ <= -1 )
replace B57_ = . if (B57_ <= -1 )
replace B58_ = . if (B58_ <= -1 )
replace B59_ = . if (B59_ <= -1 )
replace B59_2 = . if (B59_2 <= -1 )
replace B59_3 = . if (B59_3 <= -1 )
replace B59_4 = . if (B59_4 <= -1 )
replace B59_5 = . if (B59_5 <= -1 )
replace B59_6 = . if (B59_6 <= -1 )
replace B60_ = . if (B60_ <= -1 )
replace B61_ = . if (B61_ <= -1 )
replace B62_ = . if (B62_ <= -1 )
replace B63_ = . if (B63_ <= -1 )
replace B64_ = . if (B64_ <= -1 )
replace B65_ = . if (B65_ <= -1 )
replace B65_2 = . if (B65_2 <= -1 )
replace B65_3 = . if (B65_3 <= -1 )
replace B65_4 = . if (B65_4 <= -1 )
replace B65_5 = . if (B65_5 <= -1 )
replace B66_ = . if (B66_ <= -1 )
replace B67_ = . if (B67_ <= -1 )
replace B68A_CD = . if (B68A_CD <= -1 )
replace B68B_CD = . if (B68B_CD <= -1 )
replace B71_ = . if (B71_ <= -1 )
replace B72A_CD = . if (B72A_CD <= -1 )
replace B72B_CD = . if (B72B_CD <= -1 )
replace B73_ = . if (B73_ <= -1 )
replace B74_ = . if (B74_ <= -1 )
replace B75_ = . if (B75_ <= -1 )
replace B76_ = . if (B76_ <= -1 )
replace B77_ = . if (B77_ <= -1 )
replace B78_ = . if (B78_ <= -1 )
replace B79_ = . if (B79_ <= -1 )
replace B79_2 = . if (B79_2 <= -1 )
replace B79_3 = . if (B79_3 <= -1 )
replace B79_4 = . if (B79_4 <= -1 )
replace B80_ = . if (B80_ <= -1 )
replace B82_ = . if (B82_ <= -1 )
replace B84_ = . if (B84_ <= -1 )
replace B80_2 = . if (B80_2 <= -1 )
replace B82_2 = . if (B82_2 <= -1 )
replace B84_2 = . if (B84_2 <= -1 )
replace B80_3 = . if (B80_3 <= -1.0 )
replace B82_3 = . if (B82_3 <= -1 )
replace B84_3 = . if (B84_3 <= -1 )
replace B80_4 = . if (B80_4 <= -1 )
replace B82_4 = . if (B82_4 <= -1 )
replace B84_4 = . if (B84_4 <= -1 )
replace B85_ = . if (B85_ <= -1 )
replace B86_ = . if (B86_ <= -1 )
replace B87_ = . if (B87_ <= -1 )
replace B88_ = . if (B88_ <= -1 )
replace B89_ = . if (B89_ <= -1 )
replace B89_2 = . if (B89_2 <= -1 )
replace B89_3 = . if (B89_3 <= -1 )
replace B89_4 = . if (B89_4 <= -1 )
replace B90A_ = . if (B90A_ <= -1 )
replace B91_ = . if (B91_ <= -1 )
replace B92_ = . if (B92_ <= -1 )
replace B93A_CD = . if (B93A_CD <= -1 )
replace B93B_CD = . if (B93B_CD <= -1 )
replace B94_ = . if (B94_ <= -1 )
replace B95_ = . if (B95_ <= -1 )
replace B96_ = . if (B96_ <= -1 )
replace B97_ = . if (B97_ <= -1 )
replace B98_ = . if (B98_ <= -1 )
replace B99_ = . if (B99_ <= -1 )
replace B100_ = . if (B100_ <= -1 )
replace B101_ = . if (B101_ <= -1 )
replace B102_ = . if (B102_ <= -1 )
replace B102_2 = . if (B102_2 <= -1 )
replace B102_3 = . if (B102_3 <= -1 )
replace B102_4 = . if (B102_4 <= -1 )
replace B102_5 = . if (B102_5 <= -1 )
replace B102_6 = . if (B102_6 <= -1 )
replace B103_ = . if (B103_ <= -1 )
replace B104_ = . if (B104_ <= -1 )
replace B105A_CD = . if (B105A_CD <= -1 )
replace B105B_CD = . if (B105B_CD <= -1 )
replace B106_ = . if (B106_ <= -1 )
replace B107_ = . if (B107_ <= -1 )
replace B108A_CD = . if (B108A_CD <= -1 )
replace B108B_CD = . if (B108B_CD <= -1 )
replace B109_ = . if (B109_ <= -1 )
replace B110_ = . if (B110_ <= -1 )
replace B111_ = . if (B111_ <= -1 )
replace B112_ = . if (B112_ <= -1 )
replace B114_ = . if (B114_ <= -1 )
replace B115_ = . if (B115_ <= -1 )
replace B116_ = . if (B116_ <= -1 )
replace B117_ = . if (B117_ <= -1 )
replace B118_ = . if (B118_ <= -1 )
replace B118_2 = . if (B118_2 <= -1 )
replace B118_3 = . if (B118_3 <= -1 )
replace B118_4 = . if (B118_4 <= -1 )
replace B118_5 = . if (B118_5 <= -1 )
replace B118_6 = . if (B118_6 <= -1 )
replace B119_ = . if (B119_ <= -1 )
replace B120_ = . if (B120_ <= -1 )
replace B121A_CD = . if (B121A_CD <= -1 )
replace B121B_CD = . if (B121B_CD <= -1 )
replace B122_ = . if (B122_ <= -1 )
replace B123_ = . if (B123_ <= -1 )
replace B124A_CD = . if (B124A_CD <= -1 )
replace B124B_CD = . if (B124B_CD <= -1 )
replace B125_ = . if (B125_ <= -1 )
replace B126_ = . if (B126_ <= -1 )
replace B127_ = . if (B127_ <= -1 )
replace B128_ = . if (B128_ <= -1 )
replace B129_ = . if (B129_ <= -1 )
replace B130_ = . if (B130_ <= -1 )
replace B131_ = . if (B131_ <= -1 )
replace B132_ = . if (B132_ <= -1 )
replace B133_ = . if (B133_ <= -1 )
replace B133_2 = . if (B133_2 <= -1 )
replace B133_3 = . if (B133_3 <= -1 )
replace B133_4 = . if (B133_4 <= -1 )
replace B133_5 = . if (B133_5 <= -1 )
replace B133_6 = . if (B133_6 <= -1 )
replace B133_7 = . if (B133_7 <= -1 )
replace B134_ = . if (B134_ <= -1 )
replace B135_ = . if (B135_ <= -1 )
replace B136A_CD = . if (B136A_CD <= -1 )
replace B136B_CD = . if (B136B_CD <= -1 )
replace B137_ = . if (B137_ <= -1 )
replace B138_ = . if (B138_ <= -1 )
replace B139A_CD = . if (B139A_CD <= -1 )
replace B139B_CD = . if (B139B_CD <= -1 )
replace B140_ = . if (B140_ <= -1 )
replace B141_ = . if (B141_ <= -1 )
replace B142_ = . if (B142_ <= -1 )
replace B143A_CD = . if (B143A_CD <= -1 )
replace B143B_CD = . if (B143B_CD <= -1 )
replace B144_ = . if (B144_ <= -1 )
replace B145A_CD = . if (B145A_CD <= -1 )
replace B145B_CD = . if (B145B_CD <= -1 )
replace B146_ = . if (B146_ <= -1 )
replace B147_ = . if (B147_ <= -1 )
replace B148_ = . if (B148_ <= -1 )
replace B149_ = . if (B149_ <= -1 )
replace B150_ = . if (B150_ <= -1 )
replace B150_2 = . if (B150_2 <= -1 )
replace B150_3 = . if (B150_3 <= -1 )
replace B150_4 = . if (B150_4 <= -1 )
replace B150_5 = . if (B150_5 <= -1 )
replace B151_ = . if (B151_ <= -1 )
replace B152_ = . if (B152_ <= -1 )
replace B153_ = . if (B153_ <= -1 )
replace B154_ = . if (B154_ <= -1 )
replace B155_ = . if (B155_ <= -1 )
replace B156_ = . if (B156_ <= -1 )
replace B156_2 = . if (B156_2 <= -1 )
replace B156_3 = . if (B156_3 <= -1 )
replace B156_4 = . if (B156_4 <= -1 )
replace B156_5 = . if (B156_5 <= -1 )
replace B156_6 = . if (B156_6 <= -1 )
replace B156_7 = . if (B156_7 <= -1 )
replace B157_ = . if (B157_ <= -1 )
replace B158_ = . if (B158_ <= -1 )
replace B159A_CD = . if (B159A_CD <= -1 )
replace B159B_CD = . if (B159B_CD <= -1 )
replace B160_ = . if (B160_ <= -1 )
replace B161_ = . if (B161_ <= -1 )
replace B162_ = . if (B162_ <= -1 )
replace B163_ = . if (B163_ <= -1 )
replace B164A_CD = . if (B164A_CD <= -1 )
replace B164B_CD = . if (B164B_CD <= -1 )
replace B165_ = . if (B165_ <= -1 )
replace B166_ = . if (B166_ <= -1 )
replace B167_ = . if (B167_ <= -1 )
replace B168_ = . if (B168_ <= -1.0 )
replace B169_ = . if (B169_ <= -1 )
replace B170A_CD = . if (B170A_CD <= -1 )
replace B170B_CD = . if (B170B_CD <= -1 )
replace B171_ = . if (B171_ <= -1 )
replace B172_ = . if (B172_ <= -1 )
replace B173_ = . if (B173_ <= -1 )
replace B174_ = . if (B174_ <= -1 )
replace B175_ = . if (B175_ <= -1 )
replace B176A_CD = . if (B176A_CD <= -1 )
replace B176B_CD = . if (B176B_CD <= -1 )
replace B177_ = . if (B177_ <= -1 )
replace B178A_CD = . if (B178A_CD <= -1 )
replace B178B_CD = . if (B178B_CD <= -1 )
replace C1_ = . if (C1_ <= -1 )
replace C2_ = . if (C2_ <= -1 )
replace C3_ = . if (C3_ <= -1 )
replace C4_ = . if (C4_ <= -1 )
replace C5_ = . if (C5_ <= -1 )
replace C6_ = . if (C6_ <= -1 )
replace C8_ = . if (C8_ <= -1 )
replace C9_ = . if (C9_ <= -1 )
replace C10_ = . if (C10_ <= -1 )
replace C11_ = . if (C11_ <= -1 )
replace C12_ = . if (C12_ <= -1 )
replace C13_ = . if (C13_ <= -1 )
replace C14_ = . if (C14_ <= -1 )
replace C15_ = . if (C15_ <= -1 )
replace C16_ = . if (C16_ <= -1 )
replace C17_ = . if (C17_ <= -1 )
replace C18_CD = . if (C18_CD <= -1 )
replace C19_ = . if (C19_ <= -1 )
replace C20_ = . if (C20_ <= -1 )
replace C21_ = . if (C21_ <= -1 )
replace C22_CD = . if (C22_CD <= -1 )
replace C22_CD2 = . if (C22_CD2 <= -1 )
replace C22_CD3 = . if (C22_CD3 <= -1 )
replace C22_CD4 = . if (C22_CD4 <= -1 )
replace C22_CD5 = . if (C22_CD5 <= -1 )
replace C23_CD = . if (C23_CD <= -1 )
replace C24_ = . if (C24_ <= -1 )
replace C25_ = . if (C25_ <= -1 )
replace C26_ = . if (C26_ <= -1 )
replace C27_ = . if (C27_ <= -1 )
replace C28_CD = . if (C28_CD <= -1 )
replace C28_CD2 = . if (C28_CD2 <= -1 )
replace C28_CD3 = . if (C28_CD3 <= -1 )
replace C28_CD4 = . if (C28_CD4 <= -1 )
replace C28_CD5 = . if (C28_CD5 <= -1 )
replace C29_CD = . if (C29_CD <= -1 )
replace D1_ = . if (D1_ <= -1 )
replace D2_ = . if (D2_ <= -1 )
replace D3_ = . if (D3_ <= -1 )
replace D4_ = . if (D4_ <= -1 )
replace D5_ = . if (D5_ <= -1 )
replace D6_ = . if (D6_ <= -1 )
replace D7_ = . if (D7_ <= -1 )
replace D8_ = . if (D8_ <= -1 )
replace D9_ = . if (D9_ <= -1 )
replace D10_ = . if (D10_ <= -1 )
replace D11_ = . if (D11_ <= -1 )
replace D12_ = . if (D12_ <= -1 )
replace D13_ = . if (D13_ <= -1 )
replace D14_ = . if (D14_ <= -1 )
replace D15_ = . if (D15_ <= -1 )
replace D16_ = . if (D16_ <= -1 )
replace D17_ = . if (D17_ <= -1 )
replace D18_ = . if (D18_ <= -1 )
replace D19_ = . if (D19_ <= -1 )
replace D20_ = . if (D20_ <= -1 )
replace D21_ = . if (D21_ <= -1 )
replace D22_ = . if (D22_ <= -1 )
replace D23_ = . if (D23_ <= -1 )
replace D24_ = . if (D24_ <= -1 )
replace D25_ = . if (D25_ <= -1 )
replace D26_ = . if (D26_ <= -1 )
replace D27_ = . if (D27_ <= -1 )
replace D28_ = . if (D28_ <= -1 )
replace D29_ = . if (D29_ <= -1 )
replace D30_ = . if (D30_ <= -1 )
replace D31_ = . if (D31_ <= -1 )
replace D32_ = . if (D32_ <= -1 )
replace D33_ = . if (D33_ <= -1 )
replace D34_ = . if (D34_ <= -1 )
replace D35_ = . if (D35_ <= -1 )
replace D36_ = . if (D36_ <= -1 )
replace E1_ = . if (E1_ <= -1 )
replace E2_ = . if (E2_ <= -1 )
replace E2_2 = . if (E2_2 <= -1 )
replace E2_3 = . if (E2_3 <= -1 )
replace E2_4 = . if (E2_4 <= -1 )
replace E2_5 = . if (E2_5 <= -1 )
replace E2_6 = . if (E2_6 <= -1 )
replace E3_ = . if (E3_ <= -1 )
replace E4_ = . if (E4_ <= -1 )
replace E5_ = . if (E5_ <= -1 )
replace E6_ = . if (E6_ <= -1 )
replace E7_ = . if (E7_ <= -1 )
replace F1_ = . if (F1_ <= -1 )
replace F2_ = . if (F2_ <= -1 )
replace F3_ = . if (F3_ <= -1 )
replace F4_ = . if (F4_ <= -1 )
replace F5_ = . if (F5_ <= -1 )
replace F6_ = . if (F6_ <= -1 )
replace F7_ = . if (F7_ <= -1 )
replace F8_ = . if (F8_ <= -1 )
replace F10_ = . if (F10_ <= -1 )
replace F11_ = . if (F11_ <= -1 )
replace F12_ = . if (F12_ <= -1 )
replace F13_ = . if (F13_ <= -1 )
replace F14_ = . if (F14_ <= -1 )
replace F16A_ = . if (F16A_ <= -1 )
replace F16B_ = . if (F16B_ <= -1 )
replace F16C_ = . if (F16C_ <= -1 )
replace F16D_ = . if (F16D_ <= -1 )
replace F16E_ = . if (F16E_ <= -1 )
replace F16F_ = . if (F16F_ <= -1 )
replace F16G_ = . if (F16G_ <= -1 )
replace F17_ = . if (F17_ <= -1 )
replace F19_ = . if (F19_ <= -1 )
replace F20_ = . if (F20_ <= -1 )
replace F20_2 = . if (F20_2 <= -1 )
replace F20_3 = . if (F20_3 <= -1 )
replace F20_4 = . if (F20_4 <= -1 )
replace F20_5 = . if (F20_5 <= -1 )
replace F20_6 = . if (F20_6 <= -1 )
replace F20_7 = . if (F20_7 <= -1 )
replace F21_ = . if (F21_ <= -1 )
replace F22_ = . if (F22_ <= -1 )
replace F23_ = . if (F23_ <= -1 )
replace F23_2 = . if (F23_2 <= -1 )
replace F23_3 = . if (F23_3 <= -1 )
replace F23_4 = . if (F23_4 <= -1 )
replace F23_5 = . if (F23_5 <= -1 )
replace F23_6 = . if (F23_6 <= -1 )
replace F23_7 = . if (F23_7 <= -1 )
replace F24_ = . if (F24_ <= -1 )
replace F25_ = . if (F25_ <= -1 )
replace F25_2 = . if (F25_2 <= -1 )
replace F25_3 = . if (F25_3 <= -1 )
replace F25_4 = . if (F25_4 <= -1 )
replace F25_5 = . if (F25_5 <= -1 )
replace F25_6 = . if (F25_6 <= -1 )
replace F25_7 = . if (F25_7 <= -1 )
replace F26_ = . if (F26_ <= -1 )
replace F27_ = . if (F27_ <= -1 )
replace G1_ = . if (G1_ <= -1 )
replace G2A_ = . if (G2A_ <= -1 )
replace G3A_ = . if (G3A_ <= -1 )
replace G4_ = . if (G4_ <= -1 )
replace G5_ = . if (G5_ <= -1 )
replace G6_ = . if (G6_ <= -1 )
replace G7_ = . if (G7_ <= -1 )
replace G8_ = . if (G8_ <= -1 )
replace G9_ = . if (G9_ <= -1 )
replace G12_ = . if (G12_ <= -1 )
replace G13_ = . if (G13_ <= -1 )
replace G14_ = . if (G14_ <= -1 )
replace G16_ = . if (G16_ <= -1 )
replace G17_ = . if (G17_ <= -1 )
replace G17_2 = . if (G17_2 <= -1 )
replace G17_3 = . if (G17_3 <= -1 )
replace G17_4 = . if (G17_4 <= -1 )
replace G17_5 = . if (G17_5 <= -1 )
replace G17_6 = . if (G17_6 <= -1 )
replace G17_7 = . if (G17_7 <= -1 )
replace G17_8 = . if (G17_8 <= -1 )
replace G18_ = . if (G18_ <= -1 )
replace G18_2 = . if (G18_2 <= -1 )
replace G18_3 = . if (G18_3 <= -1 )
replace G18_4 = . if (G18_4 <= -1 )
replace G18_5 = . if (G18_5 <= -1 )
replace G18_6 = . if (G18_6 <= -1 )
replace G18_7 = . if (G18_7 <= -1 )
replace G19_ = . if (G19_ <= -1 )
replace G20_ = . if (G20_ <= -1 )
replace G21_ = . if (G21_ <= -1 )
replace G22_ = . if (G22_ <= -1 )
replace G22A_ = . if (G22A_ <= -1 )
replace G22B_ = . if (G22B_ <= -1 )
replace G23_ = . if (G23_ <= -1 )
replace G24_ = . if (G24_ <= -1 )
replace G24_2 = . if (G24_2 <= -1 )
replace G24_3 = . if (G24_3 <= -1 )
replace G24_4 = . if (G24_4 <= -1 )
replace G24_5 = . if (G24_5 <= -1 )
replace G25_ = . if (G25_ <= -1 )
replace G26_ = . if (G26_ <= -1 )
replace G27_ = . if (G27_ <= -1 )
replace G28_ = . if (G28_ <= -1 )
replace G29_ = . if (G29_ <= -1 )
replace G35_ = . if (G35_ <= -1 )
replace G36_ = . if (G36_ <= -1 )
replace G37_ = . if (G37_ <= -1 )
replace G38_ = . if (G38_ <= -1 )
replace G39_ = . if (G39_ <= -1 )
replace G41_ = . if (G41_ <= -1 )
replace H1A = . if (H1A <= -1 )
replace H2 = . if (H2 <= -1 )
replace H3 = . if (H3 <= -1 )
replace H4 = . if (H4 <= -1 )
replace H5 = . if (H5 <= -1 )
replace H6 = . if (H6 <= -1 )
replace H7 = . if (H7 <= -1 )
replace H8 = . if (H8 <= -1 )
replace H10 = . if (H10 <= -1 )
replace H11 = . if (H11 <= -1 )
replace H12 = . if (H12 <= -1 )
replace H15 = . if (H15 <= -1 )
replace H16 = . if (H16 <= -1 )
replace J1 = . if (J1 <= -1 )
replace J2 = . if (J2 <= -1 )
replace J3 = . if (J3 <= -1 )
replace J4 = . if (J4 <= -1 )
replace J5 = . if (J5 <= -1 )
replace J6 = . if (J6 <= -1 )
replace J7 = . if (J7 <= -1 )
replace J8 = . if (J8 <= -1 )
replace J9 = . if (J9 <= -1 )
replace J23 = . if (J23 <= -1 )
replace J24 = . if (J24 <= -1 )
replace J25 = . if (J25 <= -1 )
replace J26 = . if (J26 <= -1 )
replace J27 = . if (J27 <= -1 )
replace J28 = . if (J28 <= -1 )
replace J29 = . if (J29 <= -1 )
replace J30 = . if (J30 <= -1 )
replace J31 = . if (J31 <= -1 )
replace J32 = . if (J32 <= -1 )
replace J33 = . if (J33 <= -1 )
replace J34 = . if (J34 <= -1 )
replace J35 = . if (J35 <= -1 )
replace J36 = . if (J36 <= -1 )
replace J37 = . if (J37 <= -1 )
replace J38 = . if (J38 <= -1 )
replace J39 = . if (J39 <= -1 )
replace J40 = . if (J40 <= -1 )
replace J41 = . if (J41 <= -1 )
replace J42 = . if (J42 <= -1 )
replace J43 = . if (J43 <= -1 )
replace J44 = . if (J44 <= -1 )
replace J45 = . if (J45 <= -1 )
replace J47 = . if (J47 <= -1 )
replace J48 = . if (J48 <= -1 )
replace J49 = . if (J49 <= -1 )
replace J50 = . if (J50 <= -1 )
replace J51 = . if (J51 <= -1 )
replace J52 = . if (J52 <= -1 )
replace J53 = . if (J53 <= -1 )
replace J55 = . if (J55 <= -1 )
replace J56 = . if (J56 <= -1 )
replace J57 = . if (J57 <= -1 )
replace J58 = . if (J58 <= -1 )
replace J59 = . if (J59 <= -1 )
replace K1_ = . if (K1_ <= -1 )
replace K2_ = . if (K2_ <= -1 )
replace K3_ = . if (K3_ <= -1 )
replace K4_ = . if (K4_ <= -1 )
replace K5_ = . if (K5_ <= -1 )
replace K6_ = . if (K6_ <= -1 )
replace K7_ = . if (K7_ <= -1 )
replace K8_ = . if (K8_ <= -1 )
replace K9_ = . if (K9_ <= -1 )
replace K10_ = . if (K10_ <= -1 )
replace K11_ = . if (K11_ <= -1 )
replace K12_ = . if (K12_ <= -1 )
replace K13_ = . if (K13_ <= -1 )
replace K6_2 = . if (K6_2 <= -1 )
replace K7_2 = . if (K7_2 <= -1 )
replace K8_2 = . if (K8_2 <= -1 )
replace K9_2 = . if (K9_2 <= -1 )
replace K10_2 = . if (K10_2 <= -1 )
replace K11_2 = . if (K11_2 <= -1 )
replace K12_2 = . if (K12_2 <= -1 )
replace K13_2 = . if (K13_2 <= -1 )
replace K6_3 = . if (K6_3 <= -1 )
replace K7_3 = . if (K7_3 <= -1 )
replace K8_3 = . if (K8_3 <= -1 )
replace K9_3 = . if (K9_3 <= -1 )
replace K10_3 = . if (K10_3 <= -1 )
replace K11_3 = . if (K11_3 <= -1 )
replace K12_3 = . if (K12_3 <= -1 )
replace K13_3 = . if (K13_3 <= -1 )
replace K6_4 = . if (K6_4 <= -1 )
replace K7_4 = . if (K7_4 <= -1 )
replace K8_4 = . if (K8_4 <= -1 )
replace K9_4 = . if (K9_4 <= -1 )
replace K10_4 = . if (K10_4 <= -1 )
replace K11_4 = . if (K11_4 <= -1 )
replace K12_4 = . if (K12_4 <= -1 )
replace K13_4 = . if (K13_4 <= -1 )
replace K6_5 = . if (K6_5 <= -1 )
replace K7_5 = . if (K7_5 <= -1 )
replace K8_5 = . if (K8_5 <= -1 )
replace K9_5 = . if (K9_5 <= -1 )
replace K10_5 = . if (K10_5 <= -1 )
replace K11_5 = . if (K11_5 <= -1 )
replace K12_5 = . if (K12_5 <= -1 )
replace K13_5 = . if (K13_5 <= -1 )
replace CK1 = . if (CK1 <= -1 )
replace CK2 = . if (CK2 <= -1 )
replace CK3 = . if (CK3 <= -1 )
replace CK4 = . if (CK4 <= -1 )
replace CK5 = . if (CK5 <= -1 )
replace K14_ = . if (K14_ <= -1 )
replace K15_ = . if (K15_ <= -1 )
replace SURVEY = . if (SURVEY <= -1 )
replace WTPOP = . if (WTPOP <= -1.0000 )
replace WTSAMP = . if (WTSAMP <= -1.0000 )
replace RDDWGT = . if (RDDWGT <= -1.0000 )
replace LOTSTATE = . if (LOTSTATE <= -1 )
replace INCOME = . if (INCOME <= -1 )
replace IINCOME = . if (IINCOME <= -1 )
replace EVERPROB = . if (EVERPROB <= -1 )
replace PROB12MO = . if (PROB12MO <= -1 )
replace MARITAL = . if (MARITAL <= -1 )
replace RACETH = . if (RACETH <= -1 )
replace A2_R = . if (A2_R <= -1 )
replace A4_R = . if (A4_R <= -1 )
replace A6_R = . if (A6_R <= -1 )
replace SMSREG = . if (SMSREG <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

